@@ -11,6 +11,9 @@ __email__ = 'matt@nycresistor.com'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 
+import symphony
+
+
 class Agent():
     from .base import remove_control_characters
     from .base import test_echo
@@ -24,3 +27,4 @@ class Agent():
         self.__key__ = key
         self.__session__ = session
         self.__keymngr__ = keymngr
+        self.__rest__ = symphony.RESTful(self.__url__, self.__crt__, self.__key__, self.__session__, self.__keymngr__)
